@@ -202,13 +202,12 @@ const mockLaidoutNodes = {
             name: "Application",
             value: "mortgage-app",
             href:
-              "/multicloud/search?filters={'textsearch':'kind:application name:mortgage-app'}"
+              "/search?filters={'textsearch':'kind:application name:mortgage-app'}"
           },
           {
             name: "Namespace",
             value: "default",
-            href:
-              "/multicloud/search?filters={'textsearch':'kind:namespace name:default'}"
+            href: "/search?filters={'textsearch':'kind:namespace name:default'}"
           }
         ],
         x: 76.5,
@@ -253,13 +252,12 @@ const mockLaidoutNodes = {
             name: "Subscription",
             value: "mortgage-app-subscription",
             href:
-              "/multicloud/search?filters={'textsearch':'kind:subscription name:mortgage-app-subscription'}"
+              "/search?filters={'textsearch':'kind:subscription name:mortgage-app-subscription'}"
           },
           {
             name: "Namespace",
             value: "default",
-            href:
-              "/multicloud/search?filters={'textsearch':'kind:namespace name:default'}"
+            href: "/search?filters={'textsearch':'kind:namespace name:default'}"
           }
         ],
         x: 76.5,
@@ -302,13 +300,12 @@ const mockLaidoutNodes = {
             name: "Placements",
             value: "mortgage-app-placement",
             href:
-              "/multicloud/search?filters={'textsearch':'kind:placementrule name:mortgage-app-placement'}"
+              "/search?filters={'textsearch':'kind:placementrule name:mortgage-app-placement'}"
           },
           {
             name: "Namespace",
             value: "default",
-            href:
-              "/multicloud/search?filters={'textsearch':'kind:namespace name:default'}"
+            href: "/search?filters={'textsearch':'kind:namespace name:default'}"
           }
         ],
         x: 226.5,
@@ -397,7 +394,7 @@ const mockLaidoutNodes = {
             name: "Cluster",
             value: "localcluster",
             href:
-              "/multicloud/search?filters={'textsearch':'kind:cluster name:localcluster'}"
+              "/search?filters={'textsearch':'kind:cluster name:localcluster'}"
           }
         ],
         x: 76.5,
@@ -444,13 +441,12 @@ const mockLaidoutNodes = {
             name: "Deployable",
             value: "mortgage-app-deployable",
             href:
-              "/multicloud/search?filters={'textsearch':'kind:deployable name:mortgage-app-deployable'}"
+              "/search?filters={'textsearch':'kind:deployable name:mortgage-app-deployable'}"
           },
           {
             name: "Namespace",
             value: "default",
-            href:
-              "/multicloud/search?filters={'textsearch':'kind:namespace name:default'}"
+            href: "/search?filters={'textsearch':'kind:namespace name:default'}"
           }
         ],
         x: 151.5,
@@ -507,7 +503,7 @@ const mockLaidoutNodes = {
             name: "Deployment",
             value: "mortgage-app-deploy",
             href:
-              "/multicloud/search?filters={'textsearch':'kind:deployment name:mortgage-app-deploy'}"
+              "/search?filters={'textsearch':'kind:deployment name:mortgage-app-deploy'}"
           }
         ],
         x: 151.5,
@@ -589,7 +585,7 @@ const mockLaidoutNodes = {
             name: "Pod",
             value: "mortgage-app-deploy",
             href:
-              "/multicloud/search?filters={'textsearch':'kind:deployment name:mortgage-app-deploy'}&showrelated=pod"
+              "/search?filters={'textsearch':'kind:deployment name:mortgage-app-deploy'}&showrelated=pod"
           }
         ],
         x: 151.5,
@@ -627,13 +623,12 @@ const mockLaidoutNodes = {
             name: "Deployable",
             value: "mortgage-app-svc",
             href:
-              "/multicloud/search?filters={'textsearch':'kind:deployable name:mortgage-app-svc'}"
+              "/search?filters={'textsearch':'kind:deployable name:mortgage-app-svc'}"
           },
           {
             name: "Namespace",
             value: "default",
-            href:
-              "/multicloud/search?filters={'textsearch':'kind:namespace name:default'}"
+            href: "/search?filters={'textsearch':'kind:namespace name:default'}"
           }
         ],
         x: 1.5,
@@ -679,7 +674,7 @@ const mockLaidoutNodes = {
             name: "Service",
             value: "mortgage-app-svc",
             href:
-              "/multicloud/search?filters={'textsearch':'kind:service name:mortgage-app-svc'}"
+              "/search?filters={'textsearch':'kind:service name:mortgage-app-svc'}"
           }
         ],
         x: 1.5,
